@@ -1,4 +1,4 @@
-# $Id: Directory.pm 46950 2017-09-12 15:20:37Z anton $
+# $Id: Directory.pm 46967 2017-09-13 13:31:10Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -74,7 +74,7 @@ sub accountTemporarilyDisabled {
 
 
 sub stuff {
-	my $flattenArrays = shift;
+	my $joinArrays = shift;
 	my $entry = $self->ldapEntry;
 
 	my %userinfo;
@@ -128,7 +128,7 @@ sub stuff {
     $userinfo{studentaccount} = $uid =~ /^(s\d{6}|u\d{7})$/i;
 
 	while (my ($key, $value) = each (%userinfo)){
-		if (defined($flattenArrays)) {
+		if (defined($joinArrays)) {
 			$value = join(', ', @{$value}) if ref($value) eq 'ARRAY';
 			$value = '' unless $value;
 		}
