@@ -1,4 +1,4 @@
-# $Id: SQL.pm 42646 2014-12-02 15:49:50Z anton $
+# $Id: SQL.pm 43381 2015-05-28 16:52:16Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/SQL.pm $
 #
 # Er wordt door deze app geschreven naar adb123, die wordt eens in het uur ofzo gelezen
@@ -72,6 +72,7 @@ field 'db';
 field 'dsn', -init => 'die "no dsn configured\n"';
 field 'user', -init => 'die "no db user configured\n"';
 field 'pass' => '';
+field 'result';
 
 our $dbi_options = {
 	AutoCommit => 0,
@@ -90,6 +91,7 @@ sub new {
 	$self->{getAnr} = $db->prepare("SELECT anr FROM adb413usernaam\@lnkpg WHERE lower(usernaam) = lower(?) AND usnstat in ('A','E')");
 	$self->{previousPasswords} = $db->prepare("SELECT pw_rcrypt_after FROM adb123\@lnkdea.kub.nl WHERE anr = ? ORDER BY change_time");
 	$self->{previousSHAPasswords} = $db->prepare("SELECT pw_sha_after FROM adb123\@lnkdea.kub.nl WHERE anr = ? ORDER BY change_time");
+	$self->{deletePasswordHistory} = $db->prepare('DELETE FROM adb123@lnkdea.kub.nl WHERE anr = ?');
 	$self->{initialPassword} = $db->prepare("SELECT pwserv FROM adb113r\@lnkdea.kub.nl WHERE anr = ?");
 
 	$self->{setPwd} = $db->prepare(
@@ -106,11 +108,16 @@ sub new {
 	$self->{getLatestRcryptPassword} = $db->prepare('SELECT pw_rcrypt_after FROM adb123@lnkdea.kub.nl
 			          WHERE epoch_time = (SELECT MAX (epoch_time) FROM adb123@lnkdea.kub.nl WHERE anr=?)');
 
+	$self->{getAccountCreationDate} = $db->prepare("SELECT usnuitg FROM adb313 WHERE anr=?");
+
+	$self->{clenchPasswordHistory} = $db->prepare('DELETE FROM adb123@lnkdea.uvt.nl a WHERE NOT EXISTS (SELECT * FROM person@lnkpg.uvt.nl p WHERE p.anr = a.anr)');
+	$self->{clenchQA} = $db->prepare('DELETE FROM adb131@lnkdea.uvt.nl a WHERE NOT EXISTS (SELECT * FROM person@lnkpg.uvt.nl p WHERE p.anr = a.anr)');
+	$self->{clenchMail} = $db->prepare('DELETE FROM adb132@lnkdea.uvt.nl a WHERE NOT EXISTS (SELECT * FROM person@lnkpg.uvt.nl p WHERE p.anr = a.anr)');
+	
 	$self->db($db);
 	return $self;
 }
 
-
 sub commit {
 	$self->db->commit;
 }
@@ -139,7 +146,8 @@ sub query {
 			cluck "no parameters for query: $name!";
 		}
 
-        $q->execute(@_);
+        my $result = $q->execute(@_);
+		$self->result($result);
         return $q;
 }
 
@@ -175,7 +183,9 @@ sub query_fetchrow_hashref {
 
 sub query_do {
 	my $q = $self->query(@_);
+	my $affectedRows = $q->rows();
 	$q->finish;
+	return $affectedRows;
 }
 
 sub getQA {
@@ -194,6 +204,26 @@ sub getQAStatus {
 	return $n?1:0;
 }
 
+sub removeDeletedUsers {
+	my $res = $self->query_do('clenchPasswordHistory');
+	warn "clenchPasswordHistory removed: $res accounts";
+
+	$res = $self->query_do('clenchQA');
+	warn "clenchQA removed: $res accounts";
+
+	$res = $self->query_do('clenchMail');
+	warn "clenchMail removed: $res accounts";
+}
+
+
+sub deletePasswordHistory {
+	my $anr = shift;
+	my $affectedRows = $self->query_do('deletePasswordHistory', $anr);
+	warn "Deleted $affectedRows records for anr: $anr";
+	$affectedRows;
+}
+
+
 sub setQA {
 	my ($anr, $q1, $a1, $q2, $a2) = @_;
 	$self->query_do('deleteQA', $anr);
@@ -257,6 +287,12 @@ sub getInitialPassword {
 	return $res->[0][0];
 }
 
+sub getAccountCreationDate {
+	my $anr = shift;
+	my $res = $self->query_fetchall('getAccountCreationDate', $anr);
+#	warn Dumper($res);
+	return $res->[0][0];
+}
 
 #sub getLatestRcrtypPassword {
 #	my $anr = shift;
